#!/bin/sh
########################################################################
# File:           setup/createcontrolscript.sh                         #
# myLinux Server: Copyright (c) 2004 Michael Oberg                     #
# Version:        0.99                                                 #
# Author:         Michael Oberg <michael.oberg@mylinuxproject.de>      #
#                                                                      #
# This program is free software; you can redistribute it and/or modify #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation; either version 2 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# This program is distributed in the hope that it will be useful,      #
# but WITHOUT ANY WARRANTY; without even the implied warranty of       #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         #
# GNU General Public License for more details.                         #
#                                                                      #
# You should have received a copy of the GNU Public License along      #
# with this package; if not, write to the Free Software Foundation,    #
# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.       #
########################################################################
if [ x$1 = x ]
then
  echo "Usage: $0 <myLinux root directory>"
  exit 1
fi
LFS=$1

cat << "EOF1" > $LFS/root/install.sh
#!/bin/sh
# manual update of /root/usermanager/setup/mylinux.conf required

cd /root/usermanager/setup

echo "Configure localization"
./location.sh
echo "Creating myLinux usermanager configuration"
./mylinux.sh
echo "Configure Apache"
./apache.sh
echo "Configure Squid"
./squid.sh
echo "Configure htdig"
./htdig.sh
echo "Configure samba fileserver"
./samba.sh
echo "Configure Secure NFS fileserver"
./secnfs.sh
echo "Configure sendmail"
./sendmail.sh
echo "Configure webmail interface"
./squirrelmail.sh
echo "Configure LDAP Explorer"
./ldapexplorer.sh
echo "Configure phpMyAdmin"
./phpmyadmin.sh
echo "Configure LDAP clients (client tools, PAM etc.)"
./ldap-client.sh
echo "Configure LDAP server"
./ldap-server.sh
echo "Filling LDAP database"
./ldap-reset-db.sh
echo "Creating certificate authority"
./ca.sh
echo "Creating SSL certificates"
./ssl.sh
echo "Configure webmin LDAP modules"
./webmin.sh
echo "Configure network"
./network.sh

echo "Writing runonce script"
cat << "EOF" > /root/.profile
#!/bin/sh
PATH=$PATH:/root/usermanager/bin

if [ -e /usr/var/slapd.pid ]
then
  # slapd was started correctly
  if ps aux | grep "^root[ \t]*`cat /usr/var/slapd.pid`" > /dev/null
  then
    # slapd is still running
    if [ -e /root/runonce.sh ]
    then
      # runonce is created during setup time; it sets up the
      # root password for mySQL, the cyrus LDAP password
      # and the admin user account
      if /root/runonce.sh
      then
	rm -f /root/runonce.sh
      fi
    fi
    if [ -e /root/runonce1.sh ]
    then
      # runonce1 is created during compile time of myLinux;
      # it sets up the proxy account for PhpMyAdmin in mySQL
      # and loads the windows drivers for the PDF printer
      # (for this the samba setup in runonce.sh has to be completed)
      if /root/runonce1.sh
      then
	rm -f /root/runonce1.sh
      fi
    fi
    if [ -e /root/runonce2.sh ]
    then
      # runonce2 is created during setup time; it sets up the
      # pma password for mySQL/phpMyAdmin
      if /root/runonce2.sh
      then
	rm -f /root/runonce2.sh
      fi
    fi
  else
    echo "Warning: LDAP server was started, but is not running anymore"
  fi
else
  echo "Warning: LDAP server is not started"
fi
EOF
cat << EOF > /root/runonce.sh
#!/bin/sh
cd /root/usermanager/setup
echo "Setting mysql root password"
./mysql.sh
EOF1
if [ $LDAPSERVER = $FQHOSTNAME ]
then
  # only the LDAP server itself should create accounts and change
  # administrative passwords, because of the local operations needed
  # by these actions
  cat << "EOF1" >> $LFS/root/install.sh
echo "Setting cyrus password"
./cyrus.sh
# only after setting cyrus password it is possible to create users
# with email accounts
echo "Creating Windows Domain Administrator account and group"
./samba-runonce.sh
echo "Creating admin user"
./adminuser.sh
EOF1
fi
cat << "EOF1" >> $LFS/root/install.sh
echo "Starting background jobs - rebuilding locate and htdig databases"
rm -f /usr/local/httpd/htdig/db/* /usr/var/locatedb
nohup /usr/local/sbin/mylinux/daily.sh &
echo "Please do not shut down before the background jobs are finished."
EOF
chmod 755 /root/runonce.sh

echo "Finished."
EOF1
chmod 755 $LFS/root/install.sh

alias mkreiserfs='mkreiserfs --format 3.6'
