#!/bin/sh
########################################################################
# File:           setup/network.sh                                     #
# myLinux Server: Copyright (c) 2003 Michael Oberg                     #
# Version:        0.97                                                 #
# Author:         Michael Oberg <michael.oberg@mylinuxproject.de>      #
#                                                                      #
# This program is free software; you can redistribute it and/or modify #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation; either version 2 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# This program is distributed in the hope that it will be useful,      #
# but WITHOUT ANY WARRANTY; without even the implied warranty of       #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         #
# GNU General Public License for more details.                         #
#                                                                      #
# You should have received a copy of the GNU Public License along      #
# with this package; if not, write to the Free Software Foundation,    #
# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.       #
########################################################################
source mylinux.conf
##############################################################
# network hostname                                           #
##############################################################
echo "HOSTNAME=$HOSTNAME" > /etc/sysconfig/network
##############################################################
# nameserver (for LDAP the DNS of the LAN has to be running) #
##############################################################
if [ $USINGLOCALDNS = "yes" ]
then
  cat << EOF > /etc/resolv.conf
search $DOMAIN
nameserver 127.0.0.1
EOF
else
  NAMESERVERS=`echo $NAMESERVER | sed 's/; */ /g'`
  cat << EOF > /etc/resolv.conf
search $DOMAIN
nameserver $NAMESERVERS
EOF
fi

if [ x$IF0_ADDR = x ]
then
  HOSTADDRESS=127.0.0.1
  SUBNET=127.0.0
else
  HOSTADDRESS=$IF0_ADDR
  SUBNET=$IF0_SUBNET
fi

if `echo $SUBNET | grep '[0-9]*\.[0-9]*\.[0-9]*' > /dev/null`
then
  SUBNET_REV=`echo $SUBNET | sed 's/\([0-9]*\)\.\([0-9]*\)\.\([0-9]*\)/\3\.\2\.\1/'`
  SUBNET_FULL="$SUBNET.0"
  SUBNET_BITMASK=24
elif `echo $SUBNET | grep '[0-9]*\.[0-9]*' > /dev/null`
then
  SUBNET_REV=`echo $SUBNET | sed 's/\([0-9]*\)\.\([0-9]*\)/\2\.\1/'`
  SUBNET_FULL="$SUBNET.0.0"
  SUBNET_BITMASK=16
else
  SUBNET_REV=$SUBNET
  SUBNET_FULL="$SUBNET.0.0.0"
  SUBNET_BITMASK=8
fi

if echo "$NAMESERVER" | grep -v ';$'
then
  NAMESERVER="$NAMESERVER;"
fi

# !!!! WARNING! The server key has to be changed!!!!
cat << EOF > /home/named/etc/named.conf
options {
    directory "/etc/namedb";
    pid-file "/var/run/named.pid";
    statistics-file "/var/run/named.stats";
    forwarders { $NAMESERVER };
};
controls {
    inet 127.0.0.1 allow { localhost; } keys { rndc_key; };
};
key "rndc_key" {
    algorithm hmac-md5;
    secret "c3Ryb25nIGVub3VnaCBmb3IgYSBtYW4gYnV0IG1hZGUgZm9yIGEgd29tYW4K";
};
zone "." {
    type hint;
    file "root.hints";
};
zone "0.0.127.in-addr.arpa" {
    type master;
    file "pz/127.0.0";
};
zone "$SUBNET_REV.in-addr.arpa" {
    type master;
    file "pz/$SUBNET";
    allow-update { localhost; key rndc_key; };
};
zone "$DOMAIN" {
    type master;
    file "pz/$DOMAIN.hosts";
    allow-update { localhost; key rndc_key; };
};
zone "whitelist.$DOMAIN" {
    type master;
    file "pz/whitelist.$DOMAIN.hosts";
};
EOF
chown $NAMEDUID.$NAMEDGID /home/named/etc/named.conf
chmod 640 /home/named/etc/named.conf

cat << EOF > /home/named/etc/namedb/pz/$DOMAIN.hosts
\$ORIGIN .
\$TTL 604800	; 1 week
$DOMAIN	IN SOA	$FQHOSTNAME. root.$FQHOSTNAME. (
				184        ; serial
				172800     ; refresh (2 days)
				14400      ; retry (4 hours)
				3628800    ; expire (6 weeks)
				604800     ; minimum (1 week)
				)
		NS		$FQHOSTNAME.
		MX		10 $FQHOSTNAME.
\$ORIGIN $DOMAIN.
$HOSTNAME		A		$HOSTADDRESS
EOF
chown $NAMEDUID.$NAMEDGID /home/named/etc/namedb/pz/$DOMAIN.hosts
chmod 640 /home/named/etc/namedb/pz/$DOMAIN.hosts

cat << EOF > /home/named/etc/namedb/pz/whitelist.$DOMAIN.hosts
$TTL 5m
@	IN SOA	whitelist.$DOMAIN. root.$DOMAIN (
	2005020223  ;serial (YYYYMMDDNN format)
;	YYYYMMDDNN
	1d		; Refresh
	2h		; Retry
	30d		; Expire
	4d		; Negative cache TTL
)
		IN	NS	$FQHOSTNAME.
		IN	A	0.0.0.0
;
; test entry
2.0.0.127       IN	A	127.0.0.2
			IN	TXT "Test Entry"
;
; remember to reverse the octets!
;
; mail.gmx.net [213.165.64.20]
20.64.165.213	IN	A	127.0.0.2
; fmmailgate01.web.de [217.72.192.221]
221.192.72.217	IN	A	127.0.0.2
; fmmailgate02.web.de [217.72.192.227]
227.192.72.217	IN	A	127.0.0.2
; fmmailgate03.web.de [217.72.192.234]
234.192.72.217	IN	A	127.0.0.2
; fmmailgate04.web.de [217.72.192.242]
242.192.72.217	IN	A	127.0.0.2
; fmmailgate05.web.de [217.72.192.243]
243.192.72.217	IN	A	127.0.0.2
; fmmailgate06.web.de [217.72.192.247]
247.192.72.217	IN	A	127.0.0.2
; fmmailgate07.web.de [217.72.192.248]
248.192.72.217	IN	A	127.0.0.2
; bay15-f13.bay15.hotmail.com [65.54.185.13]
13.185.54.65	IN	A	127.0.0.2
; moutng.kundenserver.de [212.227.126.177]
177.126.227.212	IN	A	127.0.0.2
EOF
chown $NAMEDUID.$NAMEDGID /home/named/etc/namedb/pz/whitelist.$DOMAIN.hosts
chmod 640 /home/named/etc/namedb/pz/whitelist.$DOMAIN.hosts


ADDRESS_END=`echo $HOSTADDRESS | sed "s/$SUBNET\.//"`

cat << EOF > /home/named/etc/namedb/pz/$SUBNET
\$ORIGIN .
\$TTL 604800	; 1 week
$SUBNET_REV.in-addr.arpa	IN SOA	$FQHOSTNAME. root.$FQHOSTNAME. (
				123        ; serial
				172800     ; refresh (2 days)
				14400      ; retry (4 hours)
				3628800    ; expire (6 weeks)
				604800     ; minimum (1 week)
				)
			NS	$FQHOSTNAME.
\$ORIGIN $SUBNET_REV.in-addr.arpa.
$ADDRESS_END			PTR	$FQHOSTNAME.
EOF
chown $NAMEDUID.$NAMEDGID /home/named/etc/namedb/pz/$SUBNET
chmod 640 /home/named/etc/namedb/pz/$SUBNET

cat << EOF > /etc/dhcpd.conf
ddns-updates on;
ddns-update-style interim;

option netbios-name-servers $IF0_ADDR;

# option definitions common to all supported networks...
option domain-name "$DOMAIN";
option domain-name-servers $IF0_ADDR;

option subnet-mask $IF0_MASK;
option broadcast-address $IF0_BCAST;
option routers $GATEWAY_LAN_ADDR;

default-lease-time 9000;
max-lease-time 18000;

subnet $SUBNET_FULL netmask $IF0_MASK {
        option netbios-name-servers $IF0_ADDR;
        range $DHCP_RANGE;
}

zone $DOMAIN {
  primary localhost;
}

zone $SUBNET_REV.in-addr.arpa. {
  primary localhost;
}
EOF
chmod 700 /etc/dhcpd.conf
##############################################################
# /etc/hosts                                                 #
##############################################################
if [ x$IF0_ADDR = x -a x$IF1_ADDR = x -a x$IF2_ADDR = x -a x$IF3_ADDR = x ]
then
cat << EOF > /etc/hosts
# Begin /etc/hosts (no network card version)

127.0.0.1 $FQHOSTNAME $HOSTNAME localhost

# End /etc/hosts (no network card version)
EOF
else
  if [ x$IF0_ADDR = x ]
  then
    echo "Error: Network is activated, but \$IF0_ADDR is not set"
    exit 1
  else
cat << EOF > /etc/hosts
# Begin /etc/hosts (network card version)

127.0.0.1 localhost.localdomain localhost
$IF0_ADDR $FQHOSTNAME $HOSTNAME

# End /etc/hosts (network card version)
EOF
  fi
fi
##############################################################
# network devices                                            #
##############################################################
cat << EOF > /etc/sysconfig/network
HOSTNAME=$HOSTNAME
GATEWAY=$GATEWAY_EXT_ADDR
GATEWAY_IF=$GATEWAY_EXT_IF
DHCP_LIST_INTERFACES="$DHCP_LIST_INTERFACES"
FIREWALL_OUTSIDE=$FIREWALL_OUTSIDE
EOF
rm -f /etc/sysconfig/network-devices/ifconfig.*
cp -dp /etc/modules.conf /etc/modules.conf.old
# ONBOOT=yes means: activate interface in boot time
if [ ! x$IF0 = x ]
then
  cat << EOF > /etc/sysconfig/network-devices/ifconfig.$IF0
ONBOOT=yes
IP=$IF0_ADDR
NETMASK=$IF0_MASK
BROADCAST=$IF0_BCAST
EOF
  grep -v "alias[ \t]*$IF0" /etc/modules.conf > /etc/modules.conf.if
  if [ ! x$IF0_MODULE = x ]
  then
    echo "alias $IF0 $IF0_MODULE" >> /etc/modules.conf.if
  fi
  mv /etc/modules.conf.if /etc/modules.conf
fi
if [ ! x$IF1 = x ]
then
  cat << EOF > /etc/sysconfig/network-devices/ifconfig.$IF1
ONBOOT=yes
IP=$IF1_ADDR
NETMASK=$IF1_MASK
BROADCAST=$IF1_BCAST
EOF
  grep -v "alias[ \t]*$IF1" /etc/modules.conf > /etc/modules.conf.if
  if [ ! x$IF1_MODULE = x ]
  then
    echo "alias $IF1 $IF1_MODULE" >> /etc/modules.conf.if
  fi
  mv /etc/modules.conf.if /etc/modules.conf
fi
if [ ! x$IF2 = x ]
then
  cat << EOF > /etc/sysconfig/network-devices/ifconfig.$IF2
ONBOOT=yes
IP=$IF2_ADDR
NETMASK=$IF2_MASK
BROADCAST=$IF2_BCAST
EOF
  grep -v "alias[ \t]*$IF2" /etc/modules.conf > /etc/modules.conf.if
  if [ ! x$IF2_MODULE = x ]
  then
    echo "alias $IF2 $IF2_MODULE" >> /etc/modules.conf.if
  fi
  mv /etc/modules.conf.if /etc/modules.conf
fi
if [ ! x$IF3 = x ]
then
cat << EOF > /etc/sysconfig/network-devices/ifconfig.$IF3
ONBOOT=yes
IP=$IF3_ADDR
NETMASK=$IF3_MASK
BROADCAST=$IF3_BCAST
EOF
  grep -v "alias[ \t]*$IF3" /etc/modules.conf > /etc/modules.conf.if
  if [ ! x$IF3_MODULE = x ]
  then
    echo "alias $IF3 $IF3_MODULE" >> /etc/modules.conf.if
  fi
  mv /etc/modules.conf.if /etc/modules.conf
fi

cat /etc/cups/cupsd.conf-template | sed -e "s|Allow From 127.0.0.1|Allow From $SUBNET_FULL/$SUBNET_BITMASK|" > /etc/cups/cupsd.conf
